# pylint: skip-file
import os
import tempfile
import unittest

import yaml

from ..config import load


class DatabaseConnectionLoaderTestCase(unittest.TestCase):
    connections = [
        ('foo', {
            'engine': 'postgresql',
            'host': 'remote-host',
            'port': 2345,
            'name': 'dbname',
            'user': 'dbuser',
            'password': 'dbpassword'
        })
    ]

    def setUp(self):
        self.secdir = tempfile.mkdtemp()

        # Create some example database connections of various types.
        for name, params in self.connections:
            with open(os.path.join(self.secdir, name), 'w') as f:
                f.write(yaml.safe_dump(params))

    def test_load_raises_valuerror_with_config_and_no_default(self):
        with self.assertRaises(ValueError):
            load(config_dir=self.secdir)

    def test_load_connections_from_secdir(self):
        connections = load(config_dir=self.secdir,
            env={'DB_DEFAULT_CONNECTION': 'foo'})

    def test_load_connections_default_connection_is_set(self):
        connections = load(config_dir=self.secdir,
            env={'DB_DEFAULT_CONNECTION': 'foo'})
        self.assertEqual(connections['self'], connections['foo'])

    def test_load_connections_from_secdir_raises_on_non_existing_default(self):
        with self.assertRaises(LookupError):
            connections = load(config_dir=self.secdir,
                env={'DB_DEFAULT_CONNECTION': 'baz'})

    def test_default_connection_is_self(self):
        connections = load({
            'DB_ENGINE': 'sqlite',
            'DB_NAME': ':mem:'
        })
        self.assertIn('self', connections)
        self.assertEqual(len(connections.keys()), 1)



"""Provides an API for date and time related functions."""
import time


def now():
    """Return the current date and time, represented as milliseconds since the
    UNIX epoch.
    """
    return int(time.time() * 1000)



# pylint: skip-file
import unittest

from .. import http


class QueryStringParserTestCase(unittest.TestCase):

    def test_parse_with_scalars(self):
        qs = 'foo=1&bar=2'
        params = http.parse_qs(qs)
        self.assertIn('foo', params)
        self.assertIn('bar', params)
        self.assertEqual(params['foo'], '1')
        self.assertEqual(params['bar'], '2')

    def test_parse_with_list(self):
        qs = 'foo=1&bar=2&bar=3'
        params = http.parse_qs(qs)
        self.assertIn('foo', params)
        self.assertIn('bar', params)
        self.assertEqual(params['foo'], '1')
        self.assertIsInstance(params['bar'], list)
        self.assertEqual(params['bar'][0], '2')
        self.assertEqual(params['bar'][1], '3')

    def test_parse_with_list_intermixed(self):
        qs = 'bar=3&foo=1&bar=2'
        params = http.parse_qs(qs)
        self.assertIn('foo', params)
        self.assertIn('bar', params)
        self.assertEqual(params['foo'], '1')
        self.assertIsInstance(params['bar'], list)
        self.assertIn('2', params['bar'])
        self.assertIn('3', params['bar'])



#pylint: skip-file
import unittest

from .basetestselection import BaseTestSelectionTestCase


class TestStageSelectionTestCase(unittest.TestCase, BaseTestSelectionTestCase):

    def test_class_is_not_skipped_when_current_stage_matches(self):
        self.assertTestDecorator(False, self.get_class, 'foo', current_stage='foo')

    def test_class_is_skipped_when_current_stage_is_not_test_stage(self):
        self.assertTestDecorator(True, self.get_class, 'foo', current_stage='bar')

    def test_class_is_skipped_when_no_stage_specified(self):
        self.assertTestDecorator(True, self.get_class, 'foo', current_stage=None)

    def test_method_is_not_skipped_when_current_stage_matches(self):
        self.assertTestDecorator(False, self.get_method, 'foo', current_stage='foo')

    def test_method_is_skipped_when_current_stage_is_not_test_stage(self):
        self.assertTestDecorator(True, self.get_method, 'foo', current_stage='bar')

    def test_method_is_skipped_when_no_stage_specified(self):
        self.assertTestDecorator(True, self.get_method, 'foo', current_stage=None)
